==> kadaster-gds2-2.4-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstselectie/v20170401/AfgifteSelectieCriteriaType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstselectie.v20170401;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_proces.v20170401.FilterDatumTijdType;
import nl.kadaster.schemas.gds2.afgifte_proces.v20170401.KlantAfgiftenummerReeksType;
import nl.kadaster.schemas.gds2.afgifte_proces.v20170401.SorteringType;


/**
 * &lt;p&gt;Java class for AfgifteSelectieCriteriaType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="AfgifteSelectieCriteriaType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20170401}BestandKenmerken" minOccurs="0"/&amp;gt;
 *         &amp;lt;choice minOccurs="0"&amp;gt;
 *           &amp;lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401}Periode" minOccurs="0"/&amp;gt;
 *           &amp;lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401}KlantAfgiftenummerReeks" minOccurs="0"/&amp;gt;
 *         &amp;lt;/choice&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401}NogNietGerapporteerd" minOccurs="0"/&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401}Sortering" minOccurs="0"/&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401}Afgiftereferentie" minOccurs="0"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AfgifteSelectieCriteriaType", propOrder = {
    "bestandKenmerken",
    "periode",
    "klantAfgiftenummerReeks",
    "nogNietGerapporteerd",
    "sortering",
    "afgiftereferentie"
})
public class AfgifteSelectieCriteriaType {

    @XmlElement(name = "BestandKenmerken")
    protected BestandKenmerkenType bestandKenmerken;
    @XmlElement(name = "Periode", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401")
    protected FilterDatumTijdType periode;
    @XmlElement(name = "KlantAfgiftenummerReeks", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401")
    protected KlantAfgiftenummerReeksType klantAfgiftenummerReeks;
    @XmlElement(name = "NogNietGerapporteerd", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401")
    protected Boolean nogNietGerapporteerd;
    @XmlElement(name = "Sortering", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401")
    protected SorteringType sortering;
    @XmlElement(name = "Afgiftereferentie", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401")
    protected String afgiftereferentie;

    /**
     * Gets the value of the bestandKenmerken property.
     * 
     * @return
     *     possible object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public BestandKenmerkenType getBestandKenmerken() {
        return bestandKenmerken;
    }

    /**
     * Sets the value of the bestandKenmerken property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public void setBestandKenmerken(BestandKenmerkenType value) {
        this.bestandKenmerken = value;
    }

    /**
     * Gets the value of the periode property.
     * 
     * @return
     *     possible object is
     *     {@link FilterDatumTijdType }
     *     
     */
    public FilterDatumTijdType getPeriode() {
        return periode;
    }

    /**
     * Sets the value of the periode property.
     * 
     * @param value
     *     allowed object is
     *     {@link FilterDatumTijdType }
     *     
     */
    public void setPeriode(FilterDatumTijdType value) {
        this.periode = value;
    }

    /**
     * Gets the value of the klantAfgiftenummerReeks property.
     * 
     * @return
     *     possible object is
     *     {@link KlantAfgiftenummerReeksType }
     *     
     */
    public KlantAfgiftenummerReeksType getKlantAfgiftenummerReeks() {
        return klantAfgiftenummerReeks;
    }

    /**
     * Sets the value of the klantAfgiftenummerReeks property.
     * 
     * @param value
     *     allowed object is
     *     {@link KlantAfgiftenummerReeksType }
     *     
     */
    public void setKlantAfgiftenummerReeks(KlantAfgiftenummerReeksType value) {
        this.klantAfgiftenummerReeks = value;
    }

    /**
     * Gets the value of the nogNietGerapporteerd property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isNogNietGerapporteerd() {
        return nogNietGerapporteerd;
    }

    /**
     * Sets the value of the nogNietGerapporteerd property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setNogNietGerapporteerd(Boolean value) {
        this.nogNietGerapporteerd = value;
    }

    /**
     * Gets the value of the sortering property.
     * 
     * @return
     *     possible object is
     *     {@link SorteringType }
     *     
     */
    public SorteringType getSortering() {
        return sortering;
    }

    /**
     * Sets the value of the sortering property.
     * 
     * @param value
     *     allowed object is
     *     {@link SorteringType }
     *     
     */
    public void setSortering(SorteringType value) {
        this.sortering = value;
    }

    /**
     * Gets the value of the afgiftereferentie property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAfgiftereferentie() {
        return afgiftereferentie;
    }

    /**
     * Sets the value of the afgiftereferentie property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAfgiftereferentie(String value) {
        this.afgiftereferentie = value;
    }

}

==> kadaster-gds2-3.0-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstselectie/v20170401/AfgifteSelectieCriteriaType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstselectie.v20170401;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_proces.v20170401.FilterDatumTijdType;
import nl.kadaster.schemas.gds2.afgifte_proces.v20170401.KlantAfgiftenummerReeksType;
import nl.kadaster.schemas.gds2.afgifte_proces.v20170401.SorteringType;


/**
 * <p>Java class for AfgifteSelectieCriteriaType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="AfgifteSelectieCriteriaType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20170401}BestandKenmerken" minOccurs="0"/&gt;
 *         &lt;choice minOccurs="0"&gt;
 *           &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401}Periode" minOccurs="0"/&gt;
 *           &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401}KlantAfgiftenummerReeks" minOccurs="0"/&gt;
 *         &lt;/choice&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401}NogNietGerapporteerd" minOccurs="0"/&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401}Sortering" minOccurs="0"/&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401}Afgiftereferentie" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AfgifteSelectieCriteriaType", propOrder = {
    "bestandKenmerken",
    "periode",
    "klantAfgiftenummerReeks",
    "nogNietGerapporteerd",
    "sortering",
    "afgiftereferentie"
})
public class AfgifteSelectieCriteriaType {

    @XmlElement(name = "BestandKenmerken")
    protected BestandKenmerkenType bestandKenmerken;
    @XmlElement(name = "Periode", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401")
    protected FilterDatumTijdType periode;
    @XmlElement(name = "KlantAfgiftenummerReeks", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401")
    protected KlantAfgiftenummerReeksType klantAfgiftenummerReeks;
    @XmlElement(name = "NogNietGerapporteerd", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401")
    protected Boolean nogNietGerapporteerd;
    @XmlElement(name = "Sortering", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401")
    protected SorteringType sortering;
    @XmlElement(name = "Afgiftereferentie", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20170401")
    protected String afgiftereferentie;

    /**
     * Gets the value of the bestandKenmerken property.
     * 
     * @return
     *     possible object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public BestandKenmerkenType getBestandKenmerken() {
        return bestandKenmerken;
    }

    /**
     * Sets the value of the bestandKenmerken property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public void setBestandKenmerken(BestandKenmerkenType value) {
        this.bestandKenmerken = value;
    }

    /**
     * Gets the value of the periode property.
     * 
     * @return
     *     possible object is
     *     {@link FilterDatumTijdType }
     *     
     */
    public FilterDatumTijdType getPeriode() {
        return periode;
    }

    /**
     * Sets the value of the periode property.
     * 
     * @param value
     *     allowed object is
     *     {@link FilterDatumTijdType }
     *     
     */
    public void setPeriode(FilterDatumTijdType value) {
        this.periode = value;
    }

    /**
     * Gets the value of the klantAfgiftenummerReeks property.
     * 
     * @return
     *     possible object is
     *     {@link KlantAfgiftenummerReeksType }
     *     
     */
    public KlantAfgiftenummerReeksType getKlantAfgiftenummerReeks() {
        return klantAfgiftenummerReeks;
    }

    /**
     * Sets the value of the klantAfgiftenummerReeks property.
     * 
     * @param value
     *     allowed object is
     *     {@link KlantAfgiftenummerReeksType }
     *     
     */
    public void setKlantAfgiftenummerReeks(KlantAfgiftenummerReeksType value) {
        this.klantAfgiftenummerReeks = value;
    }

    /**
     * Gets the value of the nogNietGerapporteerd property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isNogNietGerapporteerd() {
        return nogNietGerapporteerd;
    }

    /**
     * Sets the value of the nogNietGerapporteerd property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setNogNietGerapporteerd(Boolean value) {
        this.nogNietGerapporteerd = value;
    }

    /**
     * Gets the value of the sortering property.
     * 
     * @return
     *     possible object is
     *     {@link SorteringType }
     *     
     */
    public SorteringType getSortering() {
        return sortering;
    }

    /**
     * Sets the value of the sortering property.
     * 
     * @param value
     *     allowed object is
     *     {@link SorteringType }
     *     
     */
    public void setSortering(SorteringType value) {
        this.sortering = value;
    }

    /**
     * Gets the value of the afgiftereferentie property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAfgiftereferentie() {
        return afgiftereferentie;
    }

    /**
     * Sets the value of the afgiftereferentie property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAfgiftereferentie(String value) {
        this.afgiftereferentie = value;
    }

}
